@@ -39,7 +39,7 @@ extern "C" {
 
 static CORBA_ORB orb = CORBA_OBJECT_NIL;
 static CORBA_Environment ev;
-static GnomeBonoboObjectFactory* factory = 0;
+static GnomeComponentFactory* factory = 0;
 
 CORBA_ORB 
 bonoguppi_orb()
@@ -60,7 +60,7 @@ static void die(const char* err)
 }
 
 static GnomeView *
-guppi_view_factory (GnomeBonoboObject *bonobo_object, void *data)
+guppi_view_factory (GnomeBonoboObject *bonobo_object, CORBA_Object obj, void *data)
 {
 	GnomeView *view;
 	GtkWidget *widget;
@@ -82,8 +82,8 @@ guppi_view_factory (GnomeBonoboObject *bonobo_object, void *data)
 /*
  * Creates new Guppi component instances
  */
-static GnomeBonoboObject *
-guppi_factory (GnomeBonoboObjectFactory *factory, const char *path, void *closure)
+static GnomeObject *
+guppi_factory (GnomeComponentFactory *factory, void *closure)
 {
 	GnomeBonoboObject *server;
 
@@ -100,7 +100,7 @@ guppi_factory (GnomeBonoboObjectFactory *factory, const char *path, void *closur
           gnome_dialog_run(GNOME_DIALOG(dialog));
           die("Could not create the Guppi Gnome BonoboObject");
 	}
-	return server;
+	return (GnomeObject*) server;
 }
 
 /*
@@ -109,7 +109,7 @@ guppi_factory (GnomeBonoboObjectFactory *factory, const char *path, void *closur
 void
 bonoguppi_init_server_factory (void)
 {
-	factory = gnome_bonobo_object_factory_new ("Guppi_server_factory", guppi_factory, NULL);
+	factory = gnome_component_factory_new ("Guppi_server_factory", guppi_factory, NULL);
 
         // Since Gnome is up at this point, we can use a dialog if there's an error.
 
