@@ -73,7 +73,7 @@ DataEdit::set_data(Data* d)
     {
       ensure_widgets();
       data_->ref();
-      data_->data_model.add_view(*this);
+      data_->data_model.add_view(this);
       change_values(data_);
       change_name(data_, data_->name());
       update_entries();
@@ -94,7 +94,7 @@ DataEdit::release_data()
 {
   if (data_ != 0)
     {
-      data_->data_model.remove_view(*this);
+      data_->data_model.remove_view(this);
       if (data_->unref() == 0) delete data_;
       data_ = 0;
     }
