@@ -83,7 +83,7 @@ DataList::set_store(DataStore* ds)
     }
   gtk_clist_thaw(GTK_CLIST(clist_));
 
-  store_->store_model.add_view(*this);
+  store_->store_model.add_view(this);
 }
 
 void 
@@ -91,7 +91,7 @@ DataList::release_store()
 {
   if (store_ != 0)
     {
-      store_->store_model.remove_view(*this);
+      store_->store_model.remove_view(this);
       store_ = 0;
     }
 }
