@@ -36,7 +36,15 @@ DataStore* guppi_datastore();
 void guppi_replace_datastore(DataStore* ds);
 
 #ifdef GNOME_ENABLE_DEBUG
-void guppi_create_debug_datasets();
+typedef enum {
+  DebugDataBasic,
+  DebugDataPie,
+  DebugDataBig,
+  DebugDataAll,
+  DebugDataTypeEnd
+} DebugDataType;
+
+void guppi_create_debug_datasets(DebugDataType type);
 #endif
 
 #endif
