@@ -240,7 +240,7 @@ BarPlot::release_state()
     {
       edit_.set_state(0); // so it won't refer to a destroyed state
 
-      state_->state_model.remove_view(*this);
+      state_->state_model.remove_view(this);
 
       guint refs = state_->unref();
       if (refs == 0)
@@ -260,7 +260,7 @@ BarPlot::set_state(BarPlotState* state)
   state_ = state;
 
   state_->ref();  
-  state_->state_model.add_view(*this);
+  state_->state_model.add_view(this);
 
   edit_.set_state(state_);
 
