@@ -536,7 +536,7 @@ guppi_axis_update (GnomeCanvasItem *item, double *update_affine, ArtSVP *clip_pa
               g_debug("Item coords %g,%g %g,%g", t0.x, t0.y, t1.x, t1.y);
 #endif
 
-              GFont* gfont = 0; // static_cast<GFont*>(ti->label_font());
+              GFont* gfont = static_cast<GFont*>(ti->font());
               
               if (gfont == 0)
                 {
@@ -559,6 +559,7 @@ guppi_axis_update (GnomeCanvasItem *item, double *update_affine, ArtSVP *clip_pa
                                         "y", txt_y,
                                         "text", ti->label().c_str(),
                                         "font_gdk", gdkfont,
+                                        "fill_color_rgba", ti->label_color().rgba(),
                                         NULL);
                 }
               else
@@ -570,6 +571,7 @@ guppi_axis_update (GnomeCanvasItem *item, double *update_affine, ArtSVP *clip_pa
                                         "y", txt_y,
                                         "text", ti->label().c_str(),
                                         "font", "fixed", // kinda bad; breaks our GuppiCanvasText cache
+                                        "fill_color_rgba", ti->label_color().rgba(),
                                         NULL);
                 }
 
