@@ -74,6 +74,35 @@ Data::cast_to_label()
   return reinterpret_cast<LabelData*>(this);
 }
 
+
+const ScalarData* 
+Data::cast_to_scalar() const
+{
+  if (type_ != Scalar) return 0;
+  return reinterpret_cast<const ScalarData*>(this);
+}
+
+const CategoricalData* 
+Data::cast_to_categorical() const
+{
+  if (type_ != Categorical) return 0;
+  return reinterpret_cast<const CategoricalData*>(this);
+}
+
+const DateData* 
+Data::cast_to_date() const
+{
+  if (type_ != Date) return 0;
+  return reinterpret_cast<const DateData*>(this);
+}
+
+const LabelData* 
+Data::cast_to_label() const
+{
+  if (type_ != Label) return 0;
+  return reinterpret_cast<const LabelData*>(this);
+}
+
 guint
 Data::ref()
 {
