@@ -32,6 +32,7 @@
 #include <vector>
 
 class GFontInternal;
+typedef struct _GnomeFont GnomeFont;
 
 class GFont : public VFont {
 public:
@@ -59,6 +60,9 @@ public:
 
   static GFont* get_font(const gchar* name, FontWeightType weight, bool italic, gint size);
   
+  // Use only in printer-gnome.cc
+  GnomeFont* gnome_font();
+
 private:
   GFontInternal* internal_;
 
