@@ -395,7 +395,8 @@ guppi_draw_scatter(XyScatter* layer,
                 }
 
               ctx.set_color(c);
-
+              ctx.set_filled(false);
+              
               if (t == MarkerStyle::DOT)
                 {
                   // optimize this case, since size is irrelevant
@@ -599,6 +600,8 @@ guppi_draw_pricebars(XyPriceBars* layer,
 
   RGB::Context ctx(rgb);
 
+  ctx.set_line_width(3);
+
   // Get the bounds of the plot area, so we can set clipping on our
   // RGB buffer target.
   double sx1, sx2, sy1, sy2;
