@@ -1970,10 +1970,37 @@ public:
 XyPrint::XyPrint() 
   : MenuEntry("guppi-xy-print", 
               _("Print"),
-              _("Print the plot (doesn't work yet, just writes junk to test.ps)"))
+              _("Print the plot"))
 {
 
 }
+class XyPrintAction : public PrintAction {
+public:
+  XyPrintAction(XyPlot* p) 
+    : plot_(p)
+    {
+      g_return_if_fail(plot_ != 0);
+
+      plot_->ref();
+    }
+
+  ~XyPrintAction() {
+    if (plot_->unref() == 0)
+      delete plot_;
+  }
+
+  void print(Printer* p) {
+    guppi_print_xy(p, plot_->state());
+    if (!p->sync())
+      gnome_error_dialog(_("Printing didn't work for some reason. We're taking patches to improve this error message. :-)"));
+    else
+      gnome_ok_dialog(_("Printing complete."));
+  }
+
+private:
+  XyPlot* plot_;
+
+};
 
 void
 XyPrint::invoke(Plot* p)
@@ -1982,16 +2009,10 @@ XyPrint::invoke(Plot* p)
 
   XyPlot* sp = static_cast<XyPlot*>(p);
   
-  Printer* pr = new GPrinter;
-
-  guppi_print_xy(pr, sp->state());
-
-  if (!pr->sync())
-    gnome_error_dialog(_("Printing didn't work, but it doesn't work anyway."));
-  else
-    gnome_ok_dialog(_("Printing (which is not really implemented) wrote some stuff to test.ps"));
-
-  delete pr;
+  PrintAction* pa = new XyPrintAction(sp);
+  
+  // get the printer via a dialog, print, and destroy the PrintAction
+  guppi_get_printer_and_print(pa, true);
 }
 
 ///////////////////////////
