@@ -34,6 +34,7 @@
 #include "datastore.h"
 #include "plotutils.h"
 #include "refcount.h"
+#include <set>
 
 class ScalarData;
 class SortedPair;
@@ -235,6 +236,50 @@ private:
   void recalc_N_points();
 };
 
+
+class XyLineStyles {
+public:
+  XyLineStyles();
+  ~XyLineStyles();
+
+  XyLineStyles* clone() const;
+
+
+  void set_style(double start, double stop, guint style_id);
+
+  guint ref() { return rc_.ref(); }
+
+  guint unref() { return rc_.unref(); }
+
+  class View : public ::View 
+  {
+  public:
+    virtual void change_styles(XyLineStyles* ls) = 0;
+  };
+
+  class Model : public ::Model<XyLineStyles::View*> {
+  public:
+    void styles_changed(XyLineStyles* m) {
+      lock_views();
+      iterator i = begin();
+      while (i != end()) {
+	(*i)->change_styles(m);
+	++i;
+      }
+      unlock_views();
+    }
+
+  };
+  
+  Model linestyles_model;  
+
+private:
+  RC rc_;
+
+  
+
+};
+
 #endif
 
 
