@@ -182,7 +182,7 @@ XyDataLayer::XyDataLayer(LayerType type, DataStore* ds)
 {
   g_return_if_fail(store_ != 0);
 
-  store_->store_model.add_view(*this);
+  store_->store_model.add_view(this);
   
   pair_ = new XyPair;
 
@@ -218,7 +218,7 @@ XyDataLayer::XyDataLayer(LayerType type, DataStore* ds)
 
 XyDataLayer::~XyDataLayer()
 {
-  store_->store_model.remove_view(*this);
+  store_->store_model.remove_view(this);
 
   release_xypair();
 }
@@ -447,7 +447,7 @@ XyDataLayer::grab_xypair(XyPair* pair)
     {
       pair->ref();
       
-      pair->pair_model.add_view(*this);
+      pair->pair_model.add_view(this);
     }
 }
 void 
@@ -455,7 +455,7 @@ XyDataLayer::release_xypair()
 {
   if (pair_ != 0)
     {
-      pair_->pair_model.remove_view(*this);
+      pair_->pair_model.remove_view(this);
       if (pair_->unref() == 0)
         {
           delete pair_;
@@ -603,7 +603,7 @@ XyScatter::grab_xymarkers(XyMarkers* markers)
       // large enough for all scatter plots using it.
       markers->reserve(npoints());
       
-      markers->markers_model.add_view(*this);
+      markers->markers_model.add_view(this);
     }
 
 }
@@ -613,7 +613,7 @@ XyScatter::release_xymarkers()
 {
   if (markers_ != 0)
     {
-      markers_->markers_model.remove_view(*this);
+      markers_->markers_model.remove_view(this);
       if (markers_->unref() == 0)
         {
           delete markers_;
