@@ -199,9 +199,11 @@ public:
   // but right now it is all scalar. will fix that soonish.
   void set_x_data(Data* d);
   ScalarData* x_data();
+  const ScalarData* x_data() const;
 
   void set_y_data(Data* d);
   ScalarData* y_data();
+  const ScalarData* y_data() const;
 
   // Number of points - generally the smaller of xdata->size() and
   // ydata->size()
@@ -447,10 +449,12 @@ public:
 
   void set_price_data(PriceType which, Data* d);
   ScalarData* price_data(PriceType which);
+  const ScalarData* price_data(PriceType which) const;
   
   // Scalar or date data will be acceptable here.
   void set_time_data(Data* d);
   Data* time_data();
+  const Data* time_data() const;
 
   guint nbars() const;
 
@@ -517,7 +521,7 @@ public:
 
   };
 
-  Model pricebars_model;
+  Model price_model;
 
 protected:  
 
