@@ -171,9 +171,9 @@ XyScatterView::XyScatterView(XyPlotState* state, XyScatter* layer)
 
   layer_->ref();
 
-  layer_->layer_model.add_view(*this);
-  layer_->data_layer_model.add_view(*this);
-  layer_->xy_scatter_model.add_view(*this);
+  layer_->layer_model.add_view(this);
+  layer_->data_layer_model.add_view(this);
+  layer_->xy_scatter_model.add_view(this);
 
   grab_palette();
 }
@@ -183,9 +183,9 @@ XyScatterView::~XyScatterView()
   if (item_ != 0)
     unrealize();
 
-  layer_->layer_model.remove_view(*this);
-  layer_->data_layer_model.remove_view(*this);
-  layer_->xy_scatter_model.remove_view(*this);
+  layer_->layer_model.remove_view(this);
+  layer_->data_layer_model.remove_view(this);
+  layer_->xy_scatter_model.remove_view(this);
 
   if (layer_->unref() == 0)
     {
@@ -361,7 +361,7 @@ XyScatterView::grab_palette()
   if (p != 0)
     {
       p->ref();
-      p->palette_model.add_view(*this);
+      p->palette_model.add_view(this);
     }
 }
 
@@ -371,7 +371,7 @@ XyScatterView::release_palette()
   MarkerPalette* p = guppi_marker_palette();
   if (p != 0)
     {
-      p->palette_model.remove_view(*this);
+      p->palette_model.remove_view(this);
       if (p->unref() == 0)
         delete p;
     }
@@ -435,8 +435,8 @@ XyLineView::XyLineView(XyPlotState* state, XyLine* layer)
 
   layer_->ref();
 
-  layer_->layer_model.add_view(*this);
-  layer_->data_layer_model.add_view(*this);
+  layer_->layer_model.add_view(this);
+  layer_->data_layer_model.add_view(this);
 }
 
 XyLineView::~XyLineView()
@@ -444,8 +444,8 @@ XyLineView::~XyLineView()
   if (item_ != 0)
     unrealize();
 
-  layer_->layer_model.remove_view(*this);
-  layer_->data_layer_model.remove_view(*this);
+  layer_->layer_model.remove_view(this);
+  layer_->data_layer_model.remove_view(this);
 
   if (layer_->unref() == 0)
     {
@@ -625,8 +625,8 @@ XyPriceView::XyPriceView(XyPlotState* state, XyPriceBars* layer)
 
   layer_->ref();
 
-  layer_->layer_model.add_view(*this);
-  layer_->price_model.add_view(*this);
+  layer_->layer_model.add_view(this);
+  layer_->price_model.add_view(this);
 }
 
 XyPriceView::~XyPriceView()
@@ -634,8 +634,8 @@ XyPriceView::~XyPriceView()
   if (item_ != 0)
     unrealize();
 
-  layer_->layer_model.remove_view(*this);
-  layer_->price_model.remove_view(*this);
+  layer_->layer_model.remove_view(this);
+  layer_->price_model.remove_view(this);
 
   if (layer_->unref() == 0)
     {
@@ -777,7 +777,8 @@ XyPlot::XyPlot(DataStore* datastore)
 XyPlot::XyPlot(XyPlotState* s)
   : Plot(ID, s->store()), state_(0), 
     group_(0), layer_group_(0), bg_(0), 
-    xpos_(0.0), ypos_(0.0)
+    xpos_(0.0), ypos_(0.0),
+    axis_edit_(0)
 {
   memset(axes_,0,sizeof(GnomeCanvasItem*)*PlotUtil::PositionTypeEnd);
   memset(axis_labels_,0,sizeof(GnomeCanvasItem*)*PlotUtil::PositionTypeEnd);
@@ -1264,7 +1265,7 @@ XyPlot::release_state()
       
       layer_views_.clear();
 
-      state_->state_model.remove_view(*this);
+      state_->state_model.remove_view(this);
 
       guint refs = state_->unref();
       if (refs == 0)
@@ -1285,7 +1286,7 @@ XyPlot::set_state(XyPlotState* state)
   state_ = state;
 
   state_->ref();  
-  state_->state_model.add_view(*this);
+  state_->state_model.add_view(this);
 
   edit_.set_state(state_);
   if (axis_edit_ != 0)
