@@ -44,11 +44,11 @@ public:
       remove_button_(0), raise_button_(0), lower_button_(0)
     {
       layer_->ref();
-      layer_->layer_model.add_view(*this);
+      layer_->layer_model.add_view(this);
     }
   virtual ~XyLayerEdit() 
     {
-      layer_->layer_model.remove_view(*this);
+      layer_->layer_model.remove_view(this);
       if (layer_->unref() == 0)
         delete layer_;
     }
@@ -479,11 +479,11 @@ public:
       x_option_.set_data(data_layer_->x_data());
       y_option_.set_data(data_layer_->y_data());
 
-      data_layer_->data_layer_model.add_view(*this);
+      data_layer_->data_layer_model.add_view(this);
     }
 
   virtual ~XyDataLayerEdit() {
-    data_layer_->data_layer_model.remove_view(*this);
+    data_layer_->data_layer_model.remove_view(this);
   }
 
   // XyDataLayer::View
@@ -716,14 +716,14 @@ XyScatterEdit::XyScatterEdit(XyScatter* layer, XyPlotState* state)
 {
   g_return_if_fail(scatter_ != 0);
 
-  scatter_->xy_scatter_model.add_view(*this);
+  scatter_->xy_scatter_model.add_view(this);
 
 
 }
 
 XyScatterEdit::~XyScatterEdit()
 {
-  scatter_->xy_scatter_model.remove_view(*this);
+  scatter_->xy_scatter_model.remove_view(this);
 }
 
 void 
@@ -859,11 +859,11 @@ public:
       open_option_.set_data(price_layer_->price_data(XyPriceBars::Open));
       close_option_.set_data(price_layer_->price_data(XyPriceBars::Close));
 
-      price_layer_->price_model.add_view(*this);
+      price_layer_->price_model.add_view(this);
     }
 
   virtual ~XyPriceEdit() {
-    price_layer_->price_model.remove_view(*this);
+    price_layer_->price_model.remove_view(this);
   }
 
   // XyPriceBars::View
@@ -1156,7 +1156,7 @@ XyPlotEdit::set_state(XyPlotState* state)
   if (state_ != 0)
     {
       state_->ref();
-      state_->state_model.add_view(*this);
+      state_->state_model.add_view(this);
 
       XyPlotState::iterator i = state_->begin();
       while (i != state_->end())
@@ -1273,7 +1273,7 @@ XyPlotEdit::release_state()
         }
       layer_views_.clear();
 
-      state_->state_model.remove_view(*this);
+      state_->state_model.remove_view(this);
 
       if (state_->unref() == 0)
         delete state_;
@@ -1617,7 +1617,7 @@ XyAxisEdit::set_state(XyPlotState* state)
   if (state_ != 0)
     {
       state_->ref();
-      state_->state_model.add_view(*this);
+      state_->state_model.add_view(this);
 
       north_.fill_from(state_->axis(PlotUtil::NORTH));
       south_.fill_from(state_->axis(PlotUtil::SOUTH));
@@ -1643,7 +1643,7 @@ XyAxisEdit::release_state()
           close();
         }
 
-      state_->state_model.remove_view(*this);
+      state_->state_model.remove_view(this);
 
       if (state_->unref() == 0)
         delete state_;
