@@ -308,13 +308,13 @@ XyAxes::grab_axis(OneAxis* oa)
 {
   oa->ref();
 
-  oa->one_model.add_view(*this);
+  oa->one_model.add_view(this);
 }
 
 void 
 XyAxes::release_an_axis(OneAxis** one)
 {
-  (*one)->one_model.remove_view(*this);
+  (*one)->one_model.remove_view(this);
   
   if ((*one)->unref() == 0)
     {
@@ -1129,7 +1129,7 @@ XyPlotState::grab_xyaxes(XyAxes* axes)
     {
       axes->ref();
       
-      axes->axes_model.add_view(*this);
+      axes->axes_model.add_view(this);
     }
 }
 
@@ -1138,7 +1138,7 @@ XyPlotState::release_xyaxes()
 {
   if (axes_ != 0)
     {
-      axes_->axes_model.remove_view(*this);
+      axes_->axes_model.remove_view(this);
       if (axes_->unref() == 0)
         {
           delete axes_;
@@ -1154,23 +1154,23 @@ XyPlotState::grab_layer(XyLayer* layer)
     {
       layer->ref();
 #if 0
-      layer->layer_model.add_view(*this);
+      layer->layer_model.add_view(this);
 
       if (layer->type() == XyLayer::ScatterLayer)
         {
           XyScatter* ss = (XyScatter*)layer->cast_to_type(XyLayer::ScatterLayer);
-          ss->xy_scatter_model.add_view(*this);
-          ss->data_layer_model.add_view(*this);
+          ss->xy_scatter_model.add_view(this);
+          ss->data_layer_model.add_view(this);
         }
       else if (layer->type() == XyLayer::LineLayer)
         {
           XyLine* sl = (XyLine*)layer->cast_to_type(XyLayer::LineLayer);
-          sl->data_layer_model.add_view(*this);
+          sl->data_layer_model.add_view(this);
         }
       else if (layer->type() == XyLayer::RelationLayer)
         {
           XyRelation* sr = (XyRelation*)layer->cast_to_type(XyLayer::RelationLayer);
-          sr->xy_relation_model.add_view(*this);
+          sr->xy_relation_model.add_view(this);
         }
 #endif
     }
@@ -1182,23 +1182,23 @@ XyPlotState::release_layer(XyLayer* layer)
   if (layer != 0)
     {
 #if 0
-      layer->layer_model.remove_view(*this);
+      layer->layer_model.remove_view(this);
 
       if (layer->type() == XyLayer::ScatterLayer)
         {
           XyScatter* ss = (XyScatter*)layer->cast_to_type(XyLayer::ScatterLayer);
-          ss->xy_scatter_model.remove_view(*this);
-          ss->data_layer_model.remove_view(*this);
+          ss->xy_scatter_model.remove_view(this);
+          ss->data_layer_model.remove_view(this);
         }
       else if (layer->type() == XyLayer::LineLayer)
         {
           XyLine* sl = (XyLine*)layer->cast_to_type(XyLayer::LineLayer);
-          sl->data_layer_model.remove_view(*this);
+          sl->data_layer_model.remove_view(this);
         }
       else if (layer->type() == XyLayer::RelationLayer)
         {
           XyRelation* sr = (XyRelation*)layer->cast_to_type(XyLayer::RelationLayer);
-          sr->xy_relation_model.remove_view(*this);
+          sr->xy_relation_model.remove_view(this);
         }
 #endif 
       if (layer->unref() == 0)
