@@ -28,6 +28,7 @@
 #include "libguppi/xyplotstate.h"
 #include "libguppi/scalardata.h"
 #include "libguppi/markerstyle.h"
+#include "libguppi/typeregistry.h"
 
 #include "scm_guppi.h"
 
@@ -126,6 +127,18 @@ static scm_smobfuns xy_funcs = {
   0 // means we can never be equal? 
 };
 
+static ScmEnumVal position_type_enum[] = {
+  { "north", PlotUtil::NORTH },
+  { "south", PlotUtil::SOUTH },
+  { "east", PlotUtil::EAST },
+  { "west", PlotUtil::WEST }
+};
+
+static ScmEnumInfo position_type_enum_info = {
+  "North-south-east-west position",
+  sizeof(position_type_enum)/sizeof(position_type_enum[0]),
+  position_type_enum
+};
 
 /////////////////////// Operations on Xy
 
@@ -137,59 +150,40 @@ GUPPI_PROC(xyp,"guppi-xy?",1,0,0,(SCM xy))
 extern bool scm_scalardatap (SCM obj);
 extern ScalarData* scm2scalardata (SCM obj);
 
-#if 0
-GUPPI_PROC(xy_set_x,"guppi-xy-set-x!",2,0,0,(SCM xy, SCM xdata))
+GUPPI_PROC(xy_set_start,"guppi-xy-set-start!",3,0,0,(SCM xy, SCM pos, SCM num))
 
 {  
-  SCM_ASSERT(XY_P(xy), xy, SCM_ARG1, "guppi-xy-set-x!");
-  SCM_ASSERT(scm_scalardatap(xdata), xdata, SCM_ARG2, "guppi-xy-set-x!");
+  SCM_ASSERT(XY_P(xy), xy, SCM_ARG1, "guppi-xy-set-start!");
+  SCM_ASSERT(gh_symbol_p(pos), pos, SCM_ARG2, "guppi-xy-set-start!");
+  SCM_ASSERT(gh_number_p(num), num, SCM_ARG3, "guppi-xy-set-start!");
 
   gh_defer_ints();
   XyPlotState* sc = SCM_TO_XY(xy);  
+  char* posname = gh_symbol2newstr(pos, NULL);
+  gint posval = 0;
+
+  if (!guppi_string_to_enum_val(&position_type_enum_info, posname, &posval))
+    {
+      free(posname);
+      gh_allow_ints();
+      guppi_scm_error("guppi-xy-set-start!", _("Bad value for axis position"));
+      return SCM_UNSPECIFIED; // not reached
+    }
+
+  free(posname);
   
-  sc->set_x_data(scm2scalardata(xdata));
-  
-  gh_allow_ints();
-  return SCM_UNSPECIFIED;
-}
-
-
-GUPPI_PROC(xy_set_y,"guppi-xy-set-y!",2,0,0,(SCM xy, SCM ydata))
-
-{  
-  SCM_ASSERT(XY_P(xy), xy, SCM_ARG1, "guppi-xy-set-y!");
-  SCM_ASSERT(scm_scalardatap(ydata), ydata, SCM_ARG2, "guppi-xy-set-y!");
-
-  gh_defer_ints();
-  XyPlotState* sc = SCM_TO_XY(xy);  
-  
-  sc->set_y_data(scm2scalardata(ydata));
-  
-  gh_allow_ints();
-  return SCM_UNSPECIFIED;
-}
-
-GUPPI_PROC(xy_set_x_start,"guppi-xy-set-x-start!",2,0,0,(SCM xy, SCM num))
-
-{  
-  SCM_ASSERT(XY_P(xy), xy, SCM_ARG1, "guppi-xy-set-x-start!");
-  SCM_ASSERT(gh_number_p(num), num, SCM_ARG2, "guppi-xy-set-x-start!");
-
-  gh_defer_ints();
-  XyPlotState* sc = SCM_TO_XY(xy);  
-  
-  Axis* ax = sc->checkout_x_axis();
+  Axis* ax = sc->checkout_axis((PlotUtil::PositionType)posval);
 
   if (ax != 0)
     {
       ax->set_start(gh_scm2double(num));
       
-      sc->checkin_x_axis(ax);
+      sc->checkin_axis((PlotUtil::PositionType)posval, ax);
     }
   else 
     {
       gh_allow_ints();
-      guppi_scm_tagged_error("already-checked-out", "guppi-xy-set-y-start!",
+      guppi_scm_tagged_error("already-checked-out", "guppi-xy-set-start!",
                              _("Axis is checked out by someone else"));
       return SCM_UNSPECIFIED;
     }
@@ -198,57 +192,40 @@ GUPPI_PROC(xy_set_x_start,"guppi-xy-set-x-start!",2,0,0,(SCM xy, SCM num))
   return SCM_UNSPECIFIED;
 }
 
-GUPPI_PROC(xy_set_y_start,"guppi-xy-set-y-start!",2,0,0,(SCM xy, SCM num))
+GUPPI_PROC(xy_set_stop,"guppi-xy-set-stop!",3,0,0,(SCM xy, SCM pos, SCM num))
 
 {  
-  SCM_ASSERT(XY_P(xy), xy, SCM_ARG1, "guppi-xy-set-y-start!");
-  SCM_ASSERT(gh_number_p(num), num, SCM_ARG2, "guppi-xy-set-y-start!");
+  SCM_ASSERT(XY_P(xy), xy, SCM_ARG1, "guppi-xy-set-stop!");
+  SCM_ASSERT(gh_symbol_p(pos), pos, SCM_ARG2, "guppi-xy-set-stop!");
+  SCM_ASSERT(gh_number_p(num), num, SCM_ARG3, "guppi-xy-set-stop!");
 
   gh_defer_ints();
   XyPlotState* sc = SCM_TO_XY(xy);  
-  
-  Axis* ax = sc->checkout_y_axis();
+  char* posname = gh_symbol2newstr(pos, NULL);
+  gint posval = 0;
 
-  if (ax != 0)
-    {
-      ax->set_start(gh_scm2double(num));
-
-      sc->checkin_y_axis(ax);
-    }
-  else 
+  if (!guppi_string_to_enum_val(&position_type_enum_info, posname, &posval))
     {
+      free(posname);
       gh_allow_ints();
-      guppi_scm_tagged_error("already-checked-out", "guppi-xy-set-y-start!",
-                             _("Axis is checked out by someone else"));
-      return SCM_UNSPECIFIED;
+      guppi_scm_error("guppi-xy-set-stop!", _("Bad value for axis position"));
+      return SCM_UNSPECIFIED; // not reached
     }
 
-  gh_allow_ints();
-  return SCM_UNSPECIFIED;
-}
-
-
-GUPPI_PROC(xy_set_x_stop,"guppi-xy-set-x-stop!",2,0,0,(SCM xy, SCM num))
-
-{  
-  SCM_ASSERT(XY_P(xy), xy, SCM_ARG1, "guppi-xy-set-x-stop!");
-  SCM_ASSERT(gh_number_p(num), num, SCM_ARG2, "guppi-xy-set-x-stop!");
-
-  gh_defer_ints();
-  XyPlotState* sc = SCM_TO_XY(xy);  
+  free(posname);
   
-  Axis* ax = sc->checkout_x_axis();
+  Axis* ax = sc->checkout_axis((PlotUtil::PositionType)posval);
 
   if (ax != 0)
     {
       ax->set_stop(gh_scm2double(num));
       
-      sc->checkin_x_axis(ax);
+      sc->checkin_axis((PlotUtil::PositionType)posval, ax);
     }
   else 
     {
       gh_allow_ints();
-      guppi_scm_tagged_error("already-checked-out", "guppi-xy-set-y-stop!",
+      guppi_scm_tagged_error("already-checked-out", "guppi-xy-set-stop!",
                              _("Axis is checked out by someone else"));
       return SCM_UNSPECIFIED;
     }
@@ -257,36 +234,6 @@ GUPPI_PROC(xy_set_x_stop,"guppi-xy-set-x-stop!",2,0,0,(SCM xy, SCM num))
   return SCM_UNSPECIFIED;
 }
 
-GUPPI_PROC(xy_set_y_stop,"guppi-xy-set-y-stop!",2,0,0,(SCM xy, SCM num))
-
-{  
-  SCM_ASSERT(XY_P(xy), xy, SCM_ARG1, "guppi-xy-set-y-stop!");
-  SCM_ASSERT(gh_number_p(num), num, SCM_ARG2, "guppi-xy-set-y-stop!");
-
-  gh_defer_ints();
-  XyPlotState* sc = SCM_TO_XY(xy);  
-  
-  Axis* ax = sc->checkout_y_axis();
-
-  if (ax != 0)
-    {
-      ax->set_stop(gh_scm2double(num));
-
-      sc->checkin_y_axis(ax);
-    }
-  else 
-    {
-      gh_allow_ints();
-      guppi_scm_tagged_error("already-checked-out", "guppi-xy-set-y-stop!",
-                             _("Axis is checked out by someone else"));
-      return SCM_UNSPECIFIED;
-    }
-
-  gh_allow_ints();
-  return SCM_UNSPECIFIED;
-}
-#endif
-
 GUPPI_PROC(xy_set_width,"guppi-xy-set-width!",2,0,0,(SCM xy, SCM num))
 
 {  
@@ -299,7 +246,9 @@ GUPPI_PROC(xy_set_width,"guppi-xy-set-width!",2,0,0,(SCM xy, SCM num))
   double w = gh_scm2double(num);
   if (w < 0.0)
     {
+      gh_allow_ints();
       guppi_scm_error("guppi-xy-set-width!", _("Xy width must be positive"));
+      return SCM_UNSPECIFIED; // not reached
     }
   
   sc->set_width(w);
@@ -321,7 +270,9 @@ GUPPI_PROC(xy_set_height,"guppi-xy-set-height!",2,0,0,(SCM xy, SCM num))
   double h = gh_scm2double(num);
   if (h < 0.0)
     {
+      gh_allow_ints();
       guppi_scm_error("guppi-xy-set-height!", _("Xy height must be positive"));
+      return SCM_UNSPECIFIED; // not reached
     }
     
   sc->set_height(h);
@@ -329,109 +280,8 @@ GUPPI_PROC(xy_set_height,"guppi-xy-set-height!",2,0,0,(SCM xy, SCM num))
   gh_allow_ints();
   return SCM_UNSPECIFIED;
 }
-#if 0
-GUPPI_PROC(xy_npoints,"guppi-xy-npoints",1,0,0,(SCM xy))
-
-{  
-  SCM_ASSERT(XY_P(xy), xy, SCM_ARG1, "guppi-xy-npoints");
-
-  gh_defer_ints();
-  XyPlotState* sc = SCM_TO_XY(xy);  
-
-  guint npoints = sc->npoints();
-
-  gh_allow_ints();
-
-  return gh_int2scm(npoints);
-}
-#endif
-
-extern bool scm_markerstylep(SCM obj);
-extern guint32 scm2markerstyle(SCM obj);
 
 #if 0
-GUPPI_PROC(xy_set_global_style,"guppi-xy-set-global-style!",2,0,0,(SCM xy, SCM markerstyle))
-{
-  SCM_ASSERT(XY_P(xy), xy, SCM_ARG1, "guppi-xy-set-global-style!");
-  SCM_ASSERT(scm_markerstylep(markerstyle), markerstyle, SCM_ARG2, "guppi-xy-set-global-style!");
-
-  gh_defer_ints();
-
-  XyPlotState* sc = SCM_TO_XY(xy);  
-  guint32 id = scm2markerstyle(markerstyle);
-
-  MarkerPalette* palette = guppi_marker_palette();
-
-  const MarkerStyle* ms = palette->get(id);
-
-  if (ms == 0)
-    guppi_scm_tagged_error("markerstyle-invalid", "guppi-xy-set-global-style!", 
-                           "This MarkerStyle is no longer in the marker palette - perhaps you removed it?");
-  
-  sc->set_global_style(id);
-
-  gh_allow_ints();
-
-  return SCM_UNSPECIFIED;
-}
-
-// This is pretty much inherently really slow.
-// But maybe it could be improved.
-GUPPI_PROC(xy_set_styles, "guppi-xy-set-points-style!",3,0,0,(SCM xy, SCM markerstyle, SCM points))
-{
-  SCM_ASSERT(XY_P(xy), xy, SCM_ARG1, "guppi-xy-set-points-style!");
-  SCM_ASSERT(scm_markerstylep(markerstyle), markerstyle, SCM_ARG2, "guppi-xy-set-points-style!");
-  SCM_ASSERT(gh_vector_p(points), points, SCM_ARG3, "guppi-xy-set-points-style!");
-
-  gh_defer_ints();
-  
-  gulong N = gh_vector_length(points);
-
-  if (N == 0)
-    {
-      // Nothing to be done.
-      return SCM_UNSPECIFIED;
-    }
-
-  double* elts = gh_scm2doubles(points);
-  
-  vector<guint> toset;
-  XyPlotState* sc = SCM_TO_XY(xy);  
-  guint npoints = sc->npoints();
-
-  gulong i = 0;
-  while (i < N)
-    {
-      if (elts[i] >= npoints)
-        {
-          free(elts);
-          guppi_scm_tagged_error("point-out-of-range", "guppi-xy-set-points-style!",
-                                 "One of the points in the vector is not in the xy");
-          return SCM_UNSPECIFIED; // not reached
-        }
-
-      toset.push_back(elts[i]);
-      ++i;
-    }
-
-  free(elts);
-
-  guint32 id = scm2markerstyle(markerstyle);
-
-  MarkerPalette* palette = guppi_marker_palette();
-
-  const MarkerStyle* ms = palette->get(id);
-
-  if (ms == 0)
-    guppi_scm_tagged_error("markerstyle-invalid", "guppi-xy-set-points-style!", 
-                           "This MarkerStyle is no longer in the marker palette - perhaps you removed it?");
-  
-  sc->set_style(toset, id);
-  
-  gh_allow_ints();
-
-  return SCM_UNSPECIFIED;
-}
 
 /// Sharing stuff between xys
 
@@ -538,6 +388,10 @@ GUPPI_PROC(xy_hoard_y_axis,"guppi-xy-hoard-y-axis!",1,0,0,(SCM xy))
 
 #endif
 
+
+extern bool scm_markerstylep(SCM obj);
+extern guint32 scm2markerstyle(SCM obj);
+
 ///////////// Layer smob
 
 static long xylayer_type_tag;
@@ -632,7 +486,297 @@ static scm_smobfuns xylayer_funcs = {
   0 // means we can never be equal? 
 };
 
+GUPPI_PROC(layerp,"guppi-xylayer?",1,0,0,(SCM layer))
+{
+  return gh_bool2scm(XYLAYER_P(layer));
+}
 
+GUPPI_PROC(xy_create_scatter_layer, "guppi-xy-make-scatter-layer!",1,0,0,(SCM xy))
+{
+  SCM_ASSERT(XY_P(xy), xy, SCM_ARG1, "guppi-xy-make-scatter-layer!");
+
+  gh_defer_ints();
+
+  XyPlotState* state = scm2xy(xy);
+
+  XyScatter* sc = new XyScatter(state->store());
+  SCM layer = xylayer2scm(sc);
+
+  state->add_layer(sc);
+
+  gh_allow_ints();
+
+  return layer;
+}
+
+GUPPI_PROC(xy_create_line_layer, "guppi-xy-make-line-layer!",1,0,0,(SCM xy))
+{
+  SCM_ASSERT(XY_P(xy), xy, SCM_ARG1, "guppi-xy-make-line-layer!");
+
+  gh_defer_ints();
+
+  XyPlotState* state = scm2xy(xy);
+
+  XyLine* ln = new XyLine(state->store());
+  SCM layer = xylayer2scm(ln);
+
+  state->add_layer(ln);
+
+  gh_allow_ints();
+
+  return layer;
+}
+
+GUPPI_PROC(xy_create_price_layer, "guppi-xy-make-pricebar-layer!",1,0,0,(SCM xy))
+{
+  SCM_ASSERT(XY_P(xy), xy, SCM_ARG1, "guppi-xy-make-pricebar-layer!");
+
+  gh_defer_ints();
+
+  XyPlotState* state = scm2xy(xy);
+
+  XyPriceBars* pb = new XyPriceBars(state->store());
+  SCM layer = xylayer2scm(pb);
+
+  state->add_layer(pb);
+
+  gh_allow_ints();
+
+  return layer;
+}
+
+GUPPI_PROC(layer_is_scatter,"guppi-xylayer-scatter?",1,0,0,(SCM layer))
+{
+  SCM_ASSERT(XYLAYER_P(layer), layer, SCM_ARG1, "guppi-xylayer-scatter?");
+
+  XyLayer* xl = SCM_TO_XYLAYER(layer);  
+
+  if (xl->type_registry()->is_a(xl->type(), XyLayer::ScatterLayer))
+    return SCM_BOOL_T;
+  else
+    return SCM_BOOL_F;
+}
+
+GUPPI_PROC(layer_is_line,"guppi-xylayer-line?",1,0,0,(SCM layer))
+{
+  SCM_ASSERT(XYLAYER_P(layer), layer, SCM_ARG1, "guppi-xylayer-line?");
+
+  XyLayer* xl = SCM_TO_XYLAYER(layer);  
+
+  if (xl->type_registry()->is_a(xl->type(), XyLayer::LineLayer))
+    return SCM_BOOL_T;
+  else
+    return SCM_BOOL_F;
+}
+
+
+GUPPI_PROC(layer_is_pricebars,"guppi-xylayer-pricebars?",1,0,0,(SCM layer))
+{
+  SCM_ASSERT(XYLAYER_P(layer), layer, SCM_ARG1, "guppi-xylayer-pricebars?");
+
+  XyLayer* xl = SCM_TO_XYLAYER(layer);  
+
+  if (xl->type_registry()->is_a(xl->type(), XyLayer::PriceLayer))
+    return SCM_BOOL_T;
+  else
+    return SCM_BOOL_F;
+}
+
+GUPPI_PROC(layer_set_x,"guppi-xylayer-set-x!",2,0,0,(SCM layer, SCM xdata))
+
+{  
+  SCM_ASSERT(XYLAYER_P(layer), layer, SCM_ARG1, "guppi-xylayer-set-x!");
+  SCM_ASSERT(scm_scalardatap(xdata), xdata, SCM_ARG2, "guppi-xylayer-set-x!");
+
+  gh_defer_ints();
+  XyLayer* xl = SCM_TO_XYLAYER(layer);  
+
+  if (!xl->type_registry()->is_a(xl->type(), XyLayer::DataLayer))
+    {
+      gh_allow_ints()
+      guppi_scm_error("guppi-xylayer-set-x!", _("Wrong type of layer; can't set X values"));
+      return SCM_UNSPECIFIED; // not reached
+    }
+
+  XyDataLayer* dl = (XyDataLayer*)xl->cast_to_type(XyLayer::DataLayer);
+
+  g_assert(dl != 0);
+
+  dl->set_x_data(scm2scalardata(xdata));
+  
+  gh_allow_ints();
+  return SCM_UNSPECIFIED;
+}
+
+
+GUPPI_PROC(layer_set_y,"guppi-xylayer-set-y!",2,0,0,(SCM layer, SCM ydata))
+
+{  
+  SCM_ASSERT(XYLAYER_P(layer), layer, SCM_ARG1, "guppi-xylayer-set-y!");
+  SCM_ASSERT(scm_scalardatap(ydata), ydata, SCM_ARG2, "guppi-xylayer-set-y!");
+
+  gh_defer_ints();
+  XyLayer* xl = SCM_TO_XYLAYER(layer);  
+
+  if (!xl->type_registry()->is_a(xl->type(), XyLayer::DataLayer))
+    {
+      gh_allow_ints()
+      guppi_scm_error("guppi-xylayer-set-x!", _("Wrong type of layer; can't set Y values"));
+      return SCM_UNSPECIFIED; // not reached
+    }
+
+  XyDataLayer* dl = (XyDataLayer*)xl->cast_to_type(XyLayer::DataLayer);
+
+  g_assert(dl != 0);
+
+  dl->set_y_data(scm2scalardata(ydata));
+  
+  gh_allow_ints();
+  return SCM_UNSPECIFIED;
+}
+
+
+GUPPI_PROC(layer_npoints,"guppi-xylayer-npoints",1,0,0,(SCM xylayer))
+
+{  
+  SCM_ASSERT(XYLAYER_P(xylayer), xylayer, SCM_ARG1, "guppi-xylayer-npoints");
+
+  gh_defer_ints();
+  XyLayer* xl = SCM_TO_XYLAYER(xylayer);  
+
+  if (!xl->type_registry()->is_a(xl->type(), XyLayer::DataLayer))
+    {
+      gh_allow_ints()
+      guppi_scm_error("guppi-xylayer-npoints!", _("Wrong type of layer; can't get number of points"));
+      return SCM_UNSPECIFIED; // not reached
+    }
+
+  XyDataLayer* dl = (XyDataLayer*)xl->cast_to_type(XyLayer::DataLayer);
+
+  g_assert(dl != 0);
+
+  guint npoints = dl->npoints();
+
+  gh_allow_ints();
+
+  return gh_int2scm(npoints);
+}
+
+GUPPI_PROC(layer_set_global_style,"guppi-xylayer-set-global-style!",2,0,0,(SCM xylayer, SCM markerstyle))
+{
+  SCM_ASSERT(XYLAYER_P(xylayer), xylayer, SCM_ARG1, "guppi-xylayer-set-global-style!");
+  SCM_ASSERT(scm_markerstylep(markerstyle), markerstyle, SCM_ARG2, "guppi-xylayer-set-global-style!");
+
+  gh_defer_ints();
+
+  XyLayer* xl = SCM_TO_XYLAYER(xylayer);  
+
+  if (!xl->type_registry()->is_a(xl->type(), XyLayer::ScatterLayer))
+    {
+      gh_allow_ints()
+      guppi_scm_error("guppi-xylayer-set-global-style!", _("Wrong type of layer; can't set style"));
+      return SCM_UNSPECIFIED; // not reached
+    }
+
+  XyScatter* sc = (XyScatter*)xl->cast_to_type(XyLayer::ScatterLayer);
+
+  g_assert(sc != 0);
+
+  guint32 id = scm2markerstyle(markerstyle);
+
+  MarkerPalette* palette = guppi_marker_palette();
+
+  const MarkerStyle* ms = palette->get(id);
+
+  if (ms == 0)
+    {
+      gh_allow_ints();
+      guppi_scm_tagged_error("markerstyle-invalid", "guppi-xylayer-set-global-style!", 
+                             "This MarkerStyle is no longer in the marker palette - perhaps you removed it?");
+      return SCM_UNSPECIFIED; // not reached
+    }
+
+  sc->set_global_style(id);
+
+  gh_allow_ints();
+
+  return SCM_UNSPECIFIED;
+}
+
+// This is pretty much inherently really slow.
+// But maybe it could be improved.
+GUPPI_PROC(xylayer_set_styles, "guppi-xylayer-set-points-style!",3,0,0,(SCM xylayer, SCM markerstyle, SCM points))
+{
+  SCM_ASSERT(XYLAYER_P(xylayer), xylayer, SCM_ARG1, "guppi-xylayer-set-points-style!");
+  SCM_ASSERT(scm_markerstylep(markerstyle), markerstyle, SCM_ARG2, "guppi-xylayer-set-points-style!");
+  SCM_ASSERT(gh_vector_p(points), points, SCM_ARG3, "guppi-xylayer-set-points-style!");
+
+  gh_defer_ints();
+
+  XyLayer* xl = SCM_TO_XYLAYER(xylayer);  
+
+  if (!xl->type_registry()->is_a(xl->type(), XyLayer::ScatterLayer))
+    {
+      gh_allow_ints()
+      guppi_scm_error("guppi-xylayer-set-global-style!", _("Wrong type of layer; can't set style"));
+      return SCM_UNSPECIFIED; // not reached
+    }
+
+  XyScatter* sc = (XyScatter*)xl->cast_to_type(XyLayer::ScatterLayer);
+
+  g_assert(sc != 0);
+  
+  gulong N = gh_vector_length(points);
+
+  if (N == 0)
+    {
+      // Nothing to be done.
+      return SCM_UNSPECIFIED;
+    }
+
+  double* elts = gh_scm2doubles(points);
+  
+  vector<guint> toset;
+  guint npoints = sc->npoints();
+
+  gulong i = 0;
+  while (i < N)
+    {
+      if (elts[i] >= npoints)
+        {
+          gh_allow_ints();
+          free(elts);
+          guppi_scm_tagged_error("point-out-of-range", "guppi-xylayer-set-points-style!",
+                                 "One of the points in the vector is not in the xylayer");
+          return SCM_UNSPECIFIED; // not reached
+        }
+
+      toset.push_back(elts[i]);
+      ++i;
+    }
+
+  free(elts);
+
+  guint32 id = scm2markerstyle(markerstyle);
+
+  MarkerPalette* palette = guppi_marker_palette();
+
+  const MarkerStyle* ms = palette->get(id);
+
+  if (ms == 0)
+    {
+      gh_allow_ints();
+      guppi_scm_tagged_error("markerstyle-invalid", "guppi-xylayer-set-points-style!", 
+                             "This MarkerStyle is no longer in the marker palette - perhaps you removed it?");
+      return SCM_UNSPECIFIED; // not reached
+    }
+
+  sc->set_style(toset, id);
+  
+  gh_allow_ints();
+
+  return SCM_UNSPECIFIED;
+}
 
 //////////////// Init
 
